@@ -21,6 +21,8 @@
 -- 2. The bound stage where the listitem references an item from the list.
 --    The [ColumnViewCell:item]("GI.Gtk.Objects.ColumnViewCell#g:attr:item") property is not 'P.Nothing'.
 -- 
+-- 
+-- 
 -- /Since: 4.12/
 
 #if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
@@ -260,6 +262,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -313,18 +316,18 @@ instance B.Types.TypedObject ColumnViewCell where
 
 instance B.Types.GObject ColumnViewCell
 
--- | Type class for types which can be safely cast to `ColumnViewCell`, for instance with `toColumnViewCell`.
+-- | Type class for types which can be safely cast to t'ColumnViewCell', for instance with `toColumnViewCell`.
 class (SP.GObject o, O.IsDescendantOf ColumnViewCell o) => IsColumnViewCell o
 instance (SP.GObject o, O.IsDescendantOf ColumnViewCell o) => IsColumnViewCell o
 
 instance O.HasParentTypes ColumnViewCell
 type instance O.ParentTypes ColumnViewCell = '[Gtk.ListItem.ListItem, GObject.Object.Object]
 
--- | Cast to `ColumnViewCell`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'ColumnViewCell', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toColumnViewCell :: (MIO.MonadIO m, IsColumnViewCell o) => o -> m ColumnViewCell
 toColumnViewCell = MIO.liftIO . B.ManagedPtr.unsafeCastTo ColumnViewCell
 
--- | Convert 'ColumnViewCell' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'ColumnViewCell' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe ColumnViewCell) where
     gvalueGType_ = c_gtk_column_view_cell_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr ColumnViewCell)
@@ -401,17 +404,17 @@ instance (info ~ ResolveColumnViewCellMethod t ColumnViewCell, O.OverloadedMetho
 #endif
 
 --- XXX Duplicated object with different types:
-  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "child", propType = TInterface (Name {namespace = "Gtk", name = "Widget"}), propFlags = [PropertyReadable,PropertyWritable], propReadNullable = Just True, propWriteNullable = Just True, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Widget used for display.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
-  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "child", propType = TInterface (Name {namespace = "Gtk", name = "Widget"}), propFlags = [PropertyReadable,PropertyWritable], propReadNullable = Just True, propWriteNullable = Just True, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Widget used for display.", sinceVersion = Nothing}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "child", propType = TInterface (Name {namespace = "Gtk", name = "Widget"}), propFlags = [PropertyReadable,PropertyWritable], propReadNullable = Just True, propWriteNullable = Just True, propSetter = Just "set_child", propGetter = Just "get_child", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Widget used for display.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "child", propType = TInterface (Name {namespace = "Gtk", name = "Widget"}), propFlags = [PropertyReadable,PropertyWritable], propReadNullable = Just True, propWriteNullable = Just True, propSetter = Just "set_child", propGetter = Just "get_child", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Widget used for display.", sinceVersion = Nothing}, propDeprecated = Nothing}
 --- XXX Duplicated object with different types:
-  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "item", propType = TInterface (Name {namespace = "GObject", name = "Object"}), propFlags = [PropertyReadable], propReadNullable = Just True, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Displayed item.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
-  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "item", propType = TInterface (Name {namespace = "GObject", name = "Object"}), propFlags = [PropertyReadable], propReadNullable = Just True, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Displayed item.", sinceVersion = Nothing}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "item", propType = TInterface (Name {namespace = "GObject", name = "Object"}), propFlags = [PropertyReadable], propReadNullable = Just True, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_item", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Displayed item.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "item", propType = TInterface (Name {namespace = "GObject", name = "Object"}), propFlags = [PropertyReadable], propReadNullable = Just True, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_item", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Displayed item.", sinceVersion = Nothing}, propDeprecated = Nothing}
 --- XXX Duplicated object with different types:
-  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "position", propType = TBasicType TUInt, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Position of the item.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
-  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "position", propType = TBasicType TUInt, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Position of the item.", sinceVersion = Nothing}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "position", propType = TBasicType TUInt, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_position", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Position of the item.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "position", propType = TBasicType TUInt, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_position", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "Position of the item.", sinceVersion = Nothing}, propDeprecated = Nothing}
 --- XXX Duplicated object with different types:
-  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "selected", propType = TBasicType TBoolean, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "If the item is currently selected.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
-  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "selected", propType = TBasicType TBoolean, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "If the item is currently selected.", sinceVersion = Nothing}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ColumnViewCell"} -> Property {propName = "selected", propType = TBasicType TBoolean, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_selected", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "If the item is currently selected.", sinceVersion = Just "4.12"}, propDeprecated = Nothing}
+  --- Name {namespace = "Gtk", name = "ListItem"} -> Property {propName = "selected", propType = TBasicType TBoolean, propFlags = [PropertyReadable], propReadNullable = Just False, propWriteNullable = Nothing, propSetter = Nothing, propGetter = Just "get_selected", propTransfer = TransferNothing, propDoc = Documentation {rawDocText = Just "If the item is currently selected.", sinceVersion = Nothing}, propDeprecated = Nothing}
 -- VVV Prop "child"
    -- Type: TInterface (Name {namespace = "Gtk", name = "Widget"})
    -- Flags: [PropertyReadable,PropertyWritable]
@@ -436,7 +439,7 @@ setColumnViewCellChild :: (MonadIO m, IsColumnViewCell o, Gtk.Widget.IsWidget a)
 setColumnViewCellChild obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyObject obj "child" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructColumnViewCellChild :: (IsColumnViewCell o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructColumnViewCellChild val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child" (P.Just val)
@@ -469,7 +472,7 @@ instance AttrInfo ColumnViewCellChildPropertyInfo where
     attrClear = clearColumnViewCellChild
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.child"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:child"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:child"
         })
 #endif
 
@@ -497,7 +500,7 @@ setColumnViewCellFocusable :: (MonadIO m, IsColumnViewCell o) => o -> Bool -> m
 setColumnViewCellFocusable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "focusable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@focusable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@focusable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructColumnViewCellFocusable :: (IsColumnViewCell o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructColumnViewCellFocusable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "focusable" val
@@ -521,7 +524,7 @@ instance AttrInfo ColumnViewCellFocusablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.focusable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:focusable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:focusable"
         })
 #endif
 
@@ -557,7 +560,7 @@ instance AttrInfo ColumnViewCellItemPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.item"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:item"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:item"
         })
 #endif
 
@@ -593,7 +596,7 @@ instance AttrInfo ColumnViewCellPositionPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.position"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:position"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:position"
         })
 #endif
 
@@ -629,7 +632,7 @@ instance AttrInfo ColumnViewCellSelectedPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.selected"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:selected"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#g:attr:selected"
         })
 #endif
 
@@ -720,7 +723,7 @@ instance (signature ~ (m (Maybe Gtk.Widget.Widget)), MonadIO m, IsColumnViewCell
 instance O.OverloadedMethodInfo ColumnViewCellGetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellGetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetChild"
         })
 
 
@@ -781,7 +784,7 @@ instance (signature ~ (m Bool), MonadIO m, IsColumnViewCell a) => O.OverloadedMe
 instance O.OverloadedMethodInfo ColumnViewCellGetFocusableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellGetFocusable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetFocusable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetFocusable"
         })
 
 
@@ -845,7 +848,7 @@ instance (signature ~ (m (Maybe GObject.Object.Object)), MonadIO m, IsColumnView
 instance O.OverloadedMethodInfo ColumnViewCellGetItemMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellGetItem",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetItem"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetItem"
         })
 
 
@@ -906,7 +909,7 @@ instance (signature ~ (m Word32), MonadIO m, IsColumnViewCell a) => O.Overloaded
 instance O.OverloadedMethodInfo ColumnViewCellGetPositionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellGetPosition",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetPosition"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetPosition"
         })
 
 
@@ -969,7 +972,7 @@ instance (signature ~ (m Bool), MonadIO m, IsColumnViewCell a) => O.OverloadedMe
 instance O.OverloadedMethodInfo ColumnViewCellGetSelectedMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellGetSelected",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetSelected"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellGetSelected"
         })
 
 
@@ -1057,7 +1060,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsColumnViewCell a, Gtk.Wi
 instance O.OverloadedMethodInfo ColumnViewCellSetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellSetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellSetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellSetChild"
         })
 
 
@@ -1144,7 +1147,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsColumnViewCell a) => O.Overlo
 instance O.OverloadedMethodInfo ColumnViewCellSetFocusableMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ColumnViewCell.columnViewCellSetFocusable",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellSetFocusable"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ColumnViewCell.html#v:columnViewCellSetFocusable"
         })
 
 
