@@ -240,6 +240,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -291,18 +292,18 @@ instance B.Types.TypedObject ListHeader where
 
 instance B.Types.GObject ListHeader
 
--- | Type class for types which can be safely cast to `ListHeader`, for instance with `toListHeader`.
+-- | Type class for types which can be safely cast to t'ListHeader', for instance with `toListHeader`.
 class (SP.GObject o, O.IsDescendantOf ListHeader o) => IsListHeader o
 instance (SP.GObject o, O.IsDescendantOf ListHeader o) => IsListHeader o
 
 instance O.HasParentTypes ListHeader
 type instance O.ParentTypes ListHeader = '[GObject.Object.Object]
 
--- | Cast to `ListHeader`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'ListHeader', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toListHeader :: (MIO.MonadIO m, IsListHeader o) => o -> m ListHeader
 toListHeader = MIO.liftIO . B.ManagedPtr.unsafeCastTo ListHeader
 
--- | Convert 'ListHeader' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'ListHeader' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe ListHeader) where
     gvalueGType_ = c_gtk_list_header_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr ListHeader)
@@ -393,7 +394,7 @@ setListHeaderChild :: (MonadIO m, IsListHeader o, Gtk.Widget.IsWidget a) => o ->
 setListHeaderChild obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyObject obj "child" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructListHeaderChild :: (IsListHeader o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructListHeaderChild val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child" (P.Just val)
@@ -426,7 +427,7 @@ instance AttrInfo ListHeaderChildPropertyInfo where
     attrClear = clearListHeaderChild
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.child"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#g:attr:child"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#g:attr:child"
         })
 #endif
 
@@ -462,7 +463,7 @@ instance AttrInfo ListHeaderEndPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.end"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#g:attr:end"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#g:attr:end"
         })
 #endif
 
@@ -498,7 +499,7 @@ instance AttrInfo ListHeaderItemPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.item"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#g:attr:item"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#g:attr:item"
         })
 #endif
 
@@ -534,7 +535,7 @@ instance AttrInfo ListHeaderNItemsPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.nItems"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#g:attr:nItems"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#g:attr:nItems"
         })
 #endif
 
@@ -570,7 +571,7 @@ instance AttrInfo ListHeaderStartPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.start"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#g:attr:start"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#g:attr:start"
         })
 #endif
 
@@ -659,7 +660,7 @@ instance (signature ~ (m (Maybe Gtk.Widget.Widget)), MonadIO m, IsListHeader a)
 instance O.OverloadedMethodInfo ListHeaderGetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderGetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetChild"
         })
 
 
@@ -719,7 +720,7 @@ instance (signature ~ (m Word32), MonadIO m, IsListHeader a) => O.OverloadedMeth
 instance O.OverloadedMethodInfo ListHeaderGetEndMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderGetEnd",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetEnd"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetEnd"
         })
 
 
@@ -783,7 +784,7 @@ instance (signature ~ (m (Maybe GObject.Object.Object)), MonadIO m, IsListHeader
 instance O.OverloadedMethodInfo ListHeaderGetItemMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderGetItem",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetItem"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetItem"
         })
 
 
@@ -842,7 +843,7 @@ instance (signature ~ (m Word32), MonadIO m, IsListHeader a) => O.OverloadedMeth
 instance O.OverloadedMethodInfo ListHeaderGetNItemsMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderGetNItems",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetNItems"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetNItems"
         })
 
 
@@ -902,7 +903,7 @@ instance (signature ~ (m Word32), MonadIO m, IsListHeader a) => O.OverloadedMeth
 instance O.OverloadedMethodInfo ListHeaderGetStartMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderGetStart",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetStart"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderGetStart"
         })
 
 
@@ -988,7 +989,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsListHeader a, Gtk.Widget
 instance O.OverloadedMethodInfo ListHeaderSetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.ListHeader.listHeaderSetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderSetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-ListHeader.html#v:listHeaderSetChild"
         })
 
 
