@@ -229,6 +229,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -289,18 +290,18 @@ instance B.Types.TypedObject TextMark where
 
 instance B.Types.GObject TextMark
 
--- | Type class for types which can be safely cast to `TextMark`, for instance with `toTextMark`.
+-- | Type class for types which can be safely cast to t'TextMark', for instance with `toTextMark`.
 class (SP.GObject o, O.IsDescendantOf TextMark o) => IsTextMark o
 instance (SP.GObject o, O.IsDescendantOf TextMark o) => IsTextMark o
 
 instance O.HasParentTypes TextMark
 type instance O.ParentTypes TextMark = '[GObject.Object.Object]
 
--- | Cast to `TextMark`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'TextMark', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toTextMark :: (MIO.MonadIO m, IsTextMark o) => o -> m TextMark
 toTextMark = MIO.liftIO . B.ManagedPtr.unsafeCastTo TextMark
 
--- | Convert 'TextMark' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'TextMark' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe TextMark) where
     gvalueGType_ = c_gtk_text_mark_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr TextMark)
@@ -381,7 +382,7 @@ instance (info ~ ResolveTextMarkMethod t TextMark, O.OverloadedMethodInfo info T
 getTextMarkLeftGravity :: (MonadIO m, IsTextMark o) => o -> m Bool
 getTextMarkLeftGravity obj = MIO.liftIO $ B.Properties.getObjectPropertyBool obj "left-gravity"
 
--- | Construct a `GValueConstruct` with valid value for the “@left-gravity@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@left-gravity@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructTextMarkLeftGravity :: (IsTextMark o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructTextMarkLeftGravity val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "left-gravity" val
@@ -405,7 +406,7 @@ instance AttrInfo TextMarkLeftGravityPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.leftGravity"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#g:attr:leftGravity"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#g:attr:leftGravity"
         })
 #endif
 
@@ -423,7 +424,7 @@ instance AttrInfo TextMarkLeftGravityPropertyInfo where
 getTextMarkName :: (MonadIO m, IsTextMark o) => o -> m (Maybe T.Text)
 getTextMarkName obj = MIO.liftIO $ B.Properties.getObjectPropertyString obj "name"
 
--- | Construct a `GValueConstruct` with valid value for the “@name@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@name@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructTextMarkName :: (IsTextMark o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructTextMarkName val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "name" (P.Just val)
@@ -447,7 +448,7 @@ instance AttrInfo TextMarkNamePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.name"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#g:attr:name"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#g:attr:name"
         })
 #endif
 
@@ -606,7 +607,7 @@ instance (signature ~ (m (Maybe Gtk.TextBuffer.TextBuffer)), MonadIO m, IsTextMa
 instance O.OverloadedMethodInfo TextMarkGetBufferMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkGetBuffer",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetBuffer"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetBuffer"
         })
 
 
@@ -665,7 +666,7 @@ instance (signature ~ (m Bool), MonadIO m, IsTextMark a) => O.OverloadedMethod T
 instance O.OverloadedMethodInfo TextMarkGetDeletedMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkGetDeleted",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetDeleted"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetDeleted"
         })
 
 
@@ -721,7 +722,7 @@ instance (signature ~ (m Bool), MonadIO m, IsTextMark a) => O.OverloadedMethod T
 instance O.OverloadedMethodInfo TextMarkGetLeftGravityMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkGetLeftGravity",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetLeftGravity"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetLeftGravity"
         })
 
 
@@ -781,7 +782,7 @@ instance (signature ~ (m (Maybe T.Text)), MonadIO m, IsTextMark a) => O.Overload
 instance O.OverloadedMethodInfo TextMarkGetNameMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkGetName",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetName"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetName"
         })
 
 
@@ -839,7 +840,7 @@ instance (signature ~ (m Bool), MonadIO m, IsTextMark a) => O.OverloadedMethod T
 instance O.OverloadedMethodInfo TextMarkGetVisibleMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkGetVisible",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetVisible"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkGetVisible"
         })
 
 
@@ -919,7 +920,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsTextMark a) => O.OverloadedMe
 instance O.OverloadedMethodInfo TextMarkSetVisibleMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.TextMark.textMarkSetVisible",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-TextMark.html#v:textMarkSetVisible"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-TextMark.html#v:textMarkSetVisible"
         })
 
 
